@@ -1,6 +1,7 @@
 import dash_bootstrap_components as dbc
 from dash import dcc, html, dash_table
 from typing import Optional, Union
+import pandas as pd
 
 card_style = {'width':"100%", 'textAlign':'center'}
 
@@ -49,7 +50,7 @@ def label_input_text(labelName:str, labelWidth:int, inputWidth:int, inputID:str,
     return dbc.Row(children=[
             dbc.Label(labelName, width=labelWidth),
             dbc.Col(
-                dcc.Input(
+                dbc.Input(
                     type="text", 
                     id=inputID, 
                     value=defaultInputValue, 
@@ -68,7 +69,7 @@ def label_input_number(labelName:str, labelWidth:int, inputWidth:int, inputID:st
     return dbc.Row(children=[
             dbc.Label(labelName, width=labelWidth),
             dbc.Col(
-                dcc.Input(
+                dbc.Input(
                     type="number", 
                     id=inputID, 
                     value=defaultInputValue,
@@ -106,7 +107,8 @@ def card(cardHeader: str, content: list ):
 
 
 def table(columnName:list, columnType:list, tableID:str, editable:bool,
-        row_deletable:bool, row_selectable:str, heightTable:Optional[str]="auto",
+        row_deletable:bool, row_selectable:str, data:Optional[list]=[], 
+        heightTable:Optional[str]="auto",
         dropdownContent:Optional[dict]={}):
     '''
     columnType: text, numeric
@@ -140,9 +142,17 @@ def table(columnName:list, columnType:list, tableID:str, editable:bool,
     style_cell_conditional = [{'if': {'column_id': columns[c]["id"]}, 'textAlign': 'left'} for c in range(len(columns))]
     style_cell_conditional.append({'if':{'column_id': 'id',},'display':'None',})
 
+    if data == []:
+        data_tuple = None
+    else:
+        dicty = {}
+        for i in range(len(data)):
+            dicty[columnName[i]] = data[i]
+        data_tuple = pd.DataFrame(dicty).to_dict('records')
+
     table_layout =  dash_table.DataTable(
                         id=tableID,
-                        data= [],
+                        data= data_tuple,
                         sort_action='native',
                         filter_action='native',
                         editable=editable,
